

#include <windows.h>

#include <vulkan/vulkan.h> // VkApplicationInfo/VkInstanceCreateInfo/VkInstance

#pragma comment(lib, "vulkan-1.lib") // link to vkCreateInstance/vkDestroyInstance

// Add debug log function (send output to the output console
// Put it inside 'printf' so we can customize the log information
// e.g., send it to a file instead of the console window - changed
// in one place (or disabled easily by commenting it out)
#include <stdio.h> // _vsnprintf

int dprintf(const char* format, ...) // debug printf
{
    static char s_printf_buf[1024];
    va_list args;
    va_start(args, format);
    _vsnprintf_s(s_printf_buf, sizeof(s_printf_buf), format, args);
    va_end(args);
    OutputDebugStringA(s_printf_buf);
    return 0;
}


int main()
{
    VkApplicationInfo    applicationInfo;
    VkInstanceCreateInfo instanceInfo;
    VkInstance           instance;

    // Filling out application description:
    // sType is mandatory
    applicationInfo.sType = VK_STRUCTURE_TYPE_APPLICATION_INFO;
    // pNext is mandatory
    applicationInfo.pNext = NULL;
    // The name of our application
    applicationInfo.pApplicationName = "Hello";
    // The name of the engine (e.g: Game engine name)
    applicationInfo.pEngineName = "Cat";
    // The version of the engine
    applicationInfo.engineVersion = 1;
    // The version of Vulkan you're using for this application (installed 1.3.236.0)
    applicationInfo.apiVersion = VK_MAKE_API_VERSION(0, 1, 3, 236);

    // Filling out instance description:
    // sType is mandatory
    instanceInfo.sType = VK_STRUCTURE_TYPE_INSTANCE_CREATE_INFO;
    // pNext is mandatory
    instanceInfo.pNext = NULL;
    // flags is mandatory
    instanceInfo.flags = 0;
    // The application info structure is then passed through the instance
    instanceInfo.pApplicationInfo = &applicationInfo;
    // Don't enable and layer
    instanceInfo.enabledLayerCount = 0;
    instanceInfo.ppEnabledLayerNames = NULL;
    // Don't enable any extensions
    instanceInfo.enabledExtensionCount = 0;
    instanceInfo.ppEnabledExtensionNames = NULL;

    // Now create the Vulkan instance
    VkResult result = vkCreateInstance(&instanceInfo, NULL, &instance);
    if (result != VK_SUCCESS) {
        dprintf( "Oh no! Faile to create instance. Error number:%d", result);
        return 0;
    }

    dprintf("Vulkan is ready!!!.");
    // code using Vulkan here....

    // Cleanup and say goodbye!
    // Always good to be free resources
    vkDestroyInstance(instance, NULL);

}// end main(..)

